summaryrefslogtreecommitdiff
path: root/usr.sbin
diff options
context:
space:
mode:
authorGilles Chehade <gilles@cvs.openbsd.org>2009-08-06 16:29:36 +0000
committerGilles Chehade <gilles@cvs.openbsd.org>2009-08-06 16:29:36 +0000
commit66885d0d296e28f4db1b48b8af3a59f782660814 (patch)
tree7b7202096acee25b89d538bcbc9ce03e2b14cba8 /usr.sbin
parentccadcb0a7561d6a31cd1088810145739909b96a1 (diff)
replace X-OpenSMPTD-Loop with Delivered-To
idea by jacekm@ a few weeks ago, discussed with pyr
Diffstat (limited to 'usr.sbin')
-rw-r--r--usr.sbin/smtpd/mta.c4
-rw-r--r--usr.sbin/smtpd/runner.c6
-rw-r--r--usr.sbin/smtpd/store.c6
3 files changed, 8 insertions, 8 deletions
diff --git a/usr.sbin/smtpd/mta.c b/usr.sbin/smtpd/mta.c
index 9864c1b66f7..72ba9215ba4 100644
--- a/usr.sbin/smtpd/mta.c
+++ b/usr.sbin/smtpd/mta.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: mta.c,v 1.63 2009/08/06 14:12:48 gilles Exp $ */
+/* $OpenBSD: mta.c,v 1.64 2009/08/06 16:29:35 gilles Exp $ */
/*
* Copyright (c) 2008 Pierre-Yves Ritschard <pyr@openbsd.org>
@@ -929,7 +929,7 @@ mta_reply_handler(struct bufferevent *bev, void *arg)
SSL_get_cipher_bits(sessionp->s_ssl, NULL));
}
- session_respond(sessionp, "X-OpenSMTPD-Loop: %s@%s",
+ session_respond(sessionp, "Delivered-To: %s@%s",
messagep->sender.user,
messagep->sender.domain);
diff --git a/usr.sbin/smtpd/runner.c b/usr.sbin/smtpd/runner.c
index fb8acd5aa96..0e64b520616 100644
--- a/usr.sbin/smtpd/runner.c
+++ b/usr.sbin/smtpd/runner.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: runner.c,v 1.57 2009/08/06 14:32:34 gilles Exp $ */
+/* $OpenBSD: runner.c,v 1.58 2009/08/06 16:29:35 gilles Exp $ */
/*
* Copyright (c) 2008 Gilles Chehade <gilles@openbsd.org>
@@ -1102,11 +1102,11 @@ runner_check_loop(struct message *messagep)
}
}
- else if (strncasecmp("X-OpenSMTPD-Loop: ", buf, 18) == 0) {
+ else if (strncasecmp("Delivered-To: ", buf, 14) == 0) {
struct path rcpt;
bzero(&chkpath, sizeof (struct path));
- if (! recipient_to_path(&chkpath, buf + 18))
+ if (! recipient_to_path(&chkpath, buf + 14))
continue;
rcpt = messagep->recipient;
diff --git a/usr.sbin/smtpd/store.c b/usr.sbin/smtpd/store.c
index d34ead07700..6f256833f91 100644
--- a/usr.sbin/smtpd/store.c
+++ b/usr.sbin/smtpd/store.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: store.c,v 1.23 2009/08/06 16:26:39 gilles Exp $ */
+/* $OpenBSD: store.c,v 1.24 2009/08/06 16:29:35 gilles Exp $ */
/*
* Copyright (c) 2008 Gilles Chehade <gilles@openbsd.org>
@@ -63,11 +63,11 @@ file_copy(FILE *dest, FILE *src, struct path *path, enum action_type type, int s
/* If we are NOT dealing with a mailer daemon copy, we have
* path set to the original recipient. In that case, we can
* add the X-OpenSMTPD-Loop header to help loop detection.
*/
if (!session && path != NULL && inheaders &&
strchr(buf, ':') == NULL && !isspace(*buf)) {
- if (fprintf(dest, "X-OpenSMTPD-Loop: %s@%s\n",
+ if (fprintf(dest, "Delivered-To: %s@%s\n",
path->user, path->domain) == -1)
return 0;
inheaders = 0;
@@ -63,11 +63,11 @@ file_copy(FILE *dest, FILE *src, struct path *path, enum action_type type, int s
/* If we are NOT dealing with a mailer daemon copy, we have
* path set to the original recipient. In that case, we can
- * add the X-OpenSMTPD-Loop header to help loop detection.
+ * add the Delivered-To header to help loop detection.
*/
if (!session && path != NULL && inheaders &&